/*
 * Segment 8 Parametrierung und Konfiguration, SWE 8.2 Parametrierung - Bibliothek
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.puk.param.lib;

/**
 * Definition der Typen von Anfragen, die über die ParameterSchnittstelle des
 * Datenverteilers an die Parametrierung gestellt werden können.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public enum ParametrierungsAnfrageTyp {

	/** Parameter schreiben. */
	PARAMETER_SCHREIBEN(1, "ParameterSchreiben"),

	/** Parameter lesen. */
	PARAMETER_LESEN(2, "ParameterLesen"),

	/** Parameter - Rückmeldung. */
	PARAMETER(3, "Parameter"),

	/** Parameter-Wurzel ermitteln. */
	SUCHE_PARAMETER_WURZEL(4, "SucheParameterWurzel"),

	/** Parameter-Wurzel-Ergebnis. */
	PARAMETER_WURZEL(5, "ParameterWurzel"),

	/** &Auml;nderbare Objekte ermitteln. */
	SUCHE_AENDERBARE_OBJEKTE(6, "SucheÄnderbareObjekte"),

	/** &Auml;nderbare Objekte - Rückmeldung. */
	AENDERBARE_OBJEKTE(7, "ÄnderbareObjekte"),

	/** Vorgänger-Objekte ermitteln. */
	SUCHE_VORGAENGER(8, "SucheVorgänger"),

	/** Vorgängerobjekte - Rückmeldung. */
	VORGAENGER(9, "Vorgänger"),

	/** * Nachfolger-Objekte ermitteln. */
	SUCHE_NACHFOLGER(10, "SucheNachfolger"),

	/** Nachfolger - Rückmeldung. */
	NACHFOLGER(11, "Nachfolger");

	/**
	 * Versions-ID für die Serialisierung des Objekts.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * liefert den Zustand für den übergebenen Code.
	 *
	 * @param searchedCode
	 *            der Code
	 * @return der Zustand
	 */
	public static ParametrierungsAnfrageTyp getTyp(final int searchedCode) {
		ParametrierungsAnfrageTyp result = null;
		for (final ParametrierungsAnfrageTyp typ : ParametrierungsAnfrageTyp.values()) {
			if (typ.getCode() == searchedCode) {
				result = typ;
				break;
			}
		}
		return result;
	}

	/** der Code der dem Typ zugeordnet ist. */
	private final int code;

	/** der Name der dem Typ zugeordnet ist. */
	private final String name;

	/**
	 * Konstruktor.
	 *
	 * @param code
	 *            der Code
	 * @param name
	 *            die Bezeichnung
	 */
	ParametrierungsAnfrageTyp(final int code, final String name) {
		this.code = code;
		this.name = name;
	}

	/**
	 * liefert den Code des Typs.
	 *
	 * @return den Code
	 */
	public Integer getCode() {
		return code;
	}

	/**
	 * liefert den beschreibenden Text des Typs.
	 *
	 * @return den Text
	 */
	public String getName() {
		return name;
	}
}
